@@ -138,12 +138,12 @@ def test_trigger_kokoro_build_for_pull_request_skips_kokoro_if_no_job_name(
     github = Mock()
     github.get_url.return_value = {
         "merged_at": "2021-01-01T09:00:00.000Z",
-        "base": {"repo": {"full_name": "googleapis/google-cloud-php"}},
-        "html_url": "https://github.com/googleapis/google-cloud-php/pulls/5",
+        "base": {"repo": {"full_name": "googleapis/google-cloud-php-bigquery"}},
+        "html_url": "https://github.com/googleapis/google-cloud-php-bigquery/pulls/5",
     }
     issue = {
         "pull_request": {
-            "url": "https://api.github.com/googleapis/google-cloud-php/pull/5"
+            "url": "https://api.github.com/googleapis/google-cloud-php-bigquery/pull/5"
         },
         "merged_at": "2021-01-01T09:00:00.000Z",
     }
@@ -159,13 +159,13 @@ def test_trigger_kokoro_build_for_pull_request_skips_kokoro_if_already_triggered
     github = Mock()
     github.get_url.return_value = {
         "merged_at": "2021-01-01T09:00:00.000Z",
-        "base": {"repo": {"full_name": "googleapis/google-cloud-php"}},
-        "html_url": "https://github.com/googleapis/google-cloud-php/pulls/5",
+        "base": {"repo": {"full_name": "googleapis/google-cloud-php-bigquery"}},
+        "html_url": "https://github.com/googleapis/google-cloud-php-bigquery/pulls/5",
         "labels": [{"id": 12345, "name": "autorelease: triggered"}],
     }
     issue = {
         "pull_request": {
-            "url": "https://api.github.com/googleapis/google-cloud-php/pull/5"
+            "url": "https://api.github.com/googleapis/google-cloud-php-bigquery/pull/5"
         },
         "merged_at": "2021-01-01T09:00:00.000Z",
     }
